@@ -396,11 +396,11 @@ CryptoConfigEntry *SMIMECryptoConfigEntries::configEntry(const char *componentNa
     CryptoConfigEntry *const entry = mConfig->entry(QLatin1String(componentName), QLatin1String(groupName), QLatin1String(entryName));
     if (!entry) {
         qCWarning(KLEOPATRA_LOG) << QStringLiteral("Backend error: gpgconf doesn't seem to know the entry for %1/%2/%3").arg(QLatin1String(componentName), QLatin1String(groupName), QLatin1String(entryName));
-        return 0;
+        return nullptr;
     }
     if (entry->argType() != argType || entry->isList() != isList) {
         qCWarning(KLEOPATRA_LOG) << QStringLiteral("Backend error: gpgconf has wrong type for %1/%2/%3: %4 %5").arg(QLatin1String(componentName), QLatin1String(groupName), QLatin1String(entryName)).arg(entry->argType()).arg(entry->isList());
-        return 0;
+        return nullptr;
     }
     return entry;
 }
